@@ -1,17 +1,24 @@
 ﻿import os.path
 import time
 import sys
+from logging import INFO, getLogger,StreamHandler
 
 import numpy as np
 import pyworld as pw
 
-sys.path.append(os.path.dirname(__file__)) #PyPIでのimpot用のパスを追加
-import flags
-import frq_io
-import wave_io
-import stretch
-import pitch
-import settings
+#sys.path.append(os.path.dirname(__file__)) #PyPIでのimpot用のパスを追加
+from . import flags
+from . import frq_io
+from . import wave_io
+from . import stretch
+from . import pitch
+from . import settings
+
+logger = getLogger(__name__)
+handler = StreamHandler()
+handler.setLevel(INFO)
+logger.setLevel(INFO)
+logger.addHandler(handler)
 
 class Resamp:
     '''Resamp
@@ -292,6 +299,10 @@ class Resamp:
         self._modulation = modulation
         self._tempo = tempo
         self._pitchbend = pitchbend
+        logger.info('input:' + input_path)
+        logger.info('cache:' + output_path)
+        logger.info('target_tone:' + target_tone)
+        logger.info('target_length:' + str(target_ms) + "ms")
 
     def parseFlags(self):
         '''
